@@ -25,8 +25,9 @@
 
 import importlib.util
 import sys
+import logging
 
-import pacman_mirrors.functions.util
+from pacman_mirrors.functions import util
 from pacman_mirrors.builder import common, fasttrack, interactive
 from pacman_mirrors.config import configuration as conf
 from pacman_mirrors.functions import cliFn
@@ -34,8 +35,7 @@ from pacman_mirrors.functions import config_setup
 from pacman_mirrors.functions import defaultFn
 from pacman_mirrors.functions import fileFn
 from pacman_mirrors.functions import httpFn
-
-from pacman_mirrors.functions import util
+from pacman_mirrors.functions import outputFn
 from pacman_mirrors.mirrors.mirror import Mirror
 from pacman_mirrors.translation import i18n
 
@@ -49,13 +49,8 @@ _ = i18n.language.gettext
 
 
 class PacmanMirrors:
-    """Class PacmanMirrors"""
-
     def __init__(self):
-        """Init"""
-        self.config = {
-            "config_file": conf.CONFIG_FILE
-        }
+        self.config = {"config_file": conf.CONFIG_FILE}
         self.continent = False
         self.custom = False
         self.default = False
@@ -75,46 +70,76 @@ class PacmanMirrors:
 
     def run(self):
         """
-        Run
         # Setup config: retunrs the config dictionary and true/false on custom
+        # Check working folders
+        # Check for static config
         # Parse commandline
-        # i686 check - change branch to x32-$branch
-        # sanitize config
         # Check network
+        # aarch64 check
+        # sanitize config
         # Update mirror pool
         # Check if mirrorlist is not to be touched - normal exit
         # Handle missing network
         # Load default mirror pool
         # Build mirror list
         """
+        # load configuration
         (self.config, self.custom) = config_setup.setup_config(self)
+
+        # ensure workdir exist
         fileFn.create_dir(self.config["work_dir"])
+
+        # check for static configuration
+        if self.config["static"]:
+            # static setup
+            self.custom = False
+            if fileFn.check_file(self.config["custom_file"]):
+                fileFn.delete_file(self.config["custom_file"])
+
+            # write enterprise mirror list
+            util.msg("Static configuration found")
+            mirrors = util.build_static_from_config(self, self.config["static"])
+            outputFn.write_static_mirror_pool(self, mirrors)
+            outputFn.write_pacman_mirror_list(self, mirrors)
+            exit(0)
+
+        ##########################################################
+        # default manjaro setup
         cliFn.parse_command_line(self, gtk_available=GTK_AVAILABLE)
+
+        # check network connection
+        self.network = httpFn.check_internet_connection(tty=self.tty)
+
+        # check for arm architecture
         util.aarch64_check(self, write=True)
+
+        # sanitize configuraiton
         if not config_setup.sanitize_config(config=self.config):
             sys.exit(2)
-        self.network = httpFn.check_internet_connection(tty=self.tty)
-        if self.config["url_mirrors_json"] and self.config["url_status_json"]:
-            # only fetch data files if configuration url are valid
-            if self.network:
-                httpFn.download_mirror_pool(config=self.config, tty=self.tty, quiet=self.quiet)
+
+        # download mirror pool if internet connection is available
+        if self.network:
+            httpFn.download_mirror_pool(
+                config=self.config, tty=self.tty, quiet=self.quiet
+            )
+
+        # conditional exit
+        # used in pacman hook to avoid changing mirror pool and mirror list on updates
         if self.no_mirrorlist:
             sys.exit(0)
+
+        # conditional reset CLI configuration
+        # if internet connection is down
         if not self.network:
             if not self.quiet:
-                pacman_mirrors.functions.util.internet_message(tty=self.tty)
+                util.internet_message(tty=self.tty)
             self.config["method"] = "random"
             self.fasttrack = False
-        """
+
         # Load configured mirror pool
-        """
         defaultFn.load_config_mirror_pool(self)
-        """
-        # Decide which type of mirrorlist to create
-        * Fasttrack
-        * Interactive
-        * Default
-        """
+
+        # Decide which type of mirrorlist to create Fasttrack/Interactive/Default
         if self.fasttrack:
             fasttrack.build_mirror_list(self, limit=self.fasttrack)
         elif self.interactive:
@@ -122,10 +147,11 @@ class PacmanMirrors:
         else:
             common.build_mirror_list(self)
 
+
 def start():
     app = PacmanMirrors()
     app.run()
 
-if __name__ == "__main__":
-   start()
 
+if __name__ == "__main__":
+    start()
